#!/usr/bin/env fades

import argparse
import itertools

import tweepy  # fades
import infoauth  # fades

URL_BASE = "http://twitter.com/{username}/status/{tweet_id}"


class Twitter:
    def __init__(self):
        cfg = infoauth.load("/home/facundo/.twapp.auth")

        auth = tweepy.OAuthHandler(cfg['consumer_token'], cfg['consumer_secret'])
        auth.set_access_token(cfg['access_token'], cfg['access_secret'])
        self.api = tweepy.API(auth)

    def timeline(self, username):
        page = 1
        while True:
            yield from self.api.user_timeline(username, page=page)
            page += 1


def main(username, quantity_limit, until_id):
    """Main entry point."""
    if username[0] == '@':
        username = username[1:]
    until_id = int(until_id)
    print("Retrieving tweets from {!r}".format(username))
    twitter = Twitter()

    timeline = twitter.timeline(username)
    for tweet in itertools.islice(timeline, quantity_limit):
        tstamp = tweet.created_at.strftime("%Y:%m:%d %H:%M:%S")
        url = URL_BASE.format(username=username, tweet_id=tweet.id)
        print(tstamp, url, tweet.text)
        if tweet.id == until_id:
            print("Done, ended by id limit")
            break
    else:
        print("Done, ended by quantity limit")


if __name__ == '__main__':
    parser = argparse.ArgumentParser()
    parser.add_argument("username")
    parser.add_argument("--quantity", action="store", type=int)
    parser.add_argument("--until", action="store")
    args = parser.parse_args()

    if not args.quantity and not args.until:
        parser.error("At least one of --quantity or --until must be provided")

    main(args.username, args.quantity, args.until)
